MODULE commons
 
 USE params

 IMPLICIT NONE

!
!     /atdata/           element data
!
!    elmchr(melmns) - element symbols
!    gmabds(melmns) - element number fractions  n(el)/n(h)
!    atmass(melmns) - atomic masses (amu)
!    aipot1(melmns) - 1st ionization potention (ev)
!    aipot2(melmns) - 2nd ionization potention (ev)
!    aipot3(melmns) - 3rd ionization potention (ev)
!    aipot4(melmns) - 4th ionization potention (ev)
!    aipot5(melmns) - 5th ionization potention (ev)
!

  CHARACTER(LEN=melmln), DIMENSION(melmns):: elmchr

  REAL(KIND=8), DIMENSION(melmns) :: gmabds,atmass,aipot1,aipot2,aipot3,aipot4,aipot5
 
!
!     /model/          model deck parameters
!
!    altau0(mlayer) - log(tau)
!    aatau0(mlayer) - tau
!    atheta(mlayer) - theta
!    apgass(mlayer) - gas pressure
!    apelec(mlayer) - electron pressure
!    akapp0(mlayer) - kappa
!    atelec(mlayer) - electron temperature
!    anelec(mlayer) - electron density
!    nlayer         - number of layers in model atmosphere
!    cmodel         - name of model either filename or teff and log g
!
    CHARACTER(LEN=mtitle):: cmodel
      
    INTEGER:: nlayer

    REAL(KIND=8), DIMENSION(mlayer):: altau0,aatau0,atheta,apgass,apelec,akapp0,&
                              atelec,anelec

!
!     /xlines/         line buffer
!
!    xwaves(mlines) - wavelength (a)
!    idents(mlines) - element number
!    ionsts(mlines) - ionization stage (ev)
!    expots(mlines) - lower level ex!tation potential (ev)
!    gfvals(mlines) - log gf
!    g1vals(mlines) - radiative damping constant
!    g2vals(mlines) - van der vaals damping constant
!    g3vals(mlines) - stark damping constant
!    abunds(mlines) - log a
!    eqwids(mlines) - equivalent width (a)
!    catref(mlines) - atomic data reference
!    nlines         - number of lines in buffer
!
    CHARACTER(LEN=4), DIMENSION(mlines):: catref

    INTEGER:: nlines
    INTEGER, DIMENSION(mlines):: idents,ionsts
    
    REAL(KIND=8), DIMENSION(mlines):: xwaves

    REAL(KIND=8), DIMENSION(mlines):: expots,gfvals,g1vals,g2vals,g3vals,abunds,eqwids

!
!     /radial/         cloud data
!
!    ataucl(mlayer) - log tau values of cloud
!    afclou(mlayer) - d(log a) values for each log tau value
!    ncloud         - number of cloud points
!    fcloud(mlayer) - abundance scaling factors for each altauo value
!    identc         - identification of cloud element
!
     INTEGER:: ncloud, identc

     REAL(KIND=8), DIMENSION(mlayer):: ataucl,afclou,fcloud
     
!
!     /dumb/           dumps
!
!    idumps(10)     - dump flag array
!
     INTEGER, DIMENSION(10):: idumps
!
!     /freq/
!
!    xwavlh         -
!    aehvkt(mlayer) -
!    akappa(mlayer) -
!    arhonu(mlayer) -
!    ataunu(mlayer) -
!
     REAL(KIND=8):: xwavlh
     REAL(KIND=8), DIMENSION(mlayer):: aehvkt,akappa,arhonu,ataunu

!
!     /line/           current line data
!
!    identl         - element atomic number
!    ionstl         - ionization stage
!    xwavel         - wavelength (a)
!    expotl         - lower level ex!tation potential (ev)
!    gfvall         - log gf
!    g1vall         - radiative damping constant
!    g2vall         - van der waals damping constant
!    g3vall         - stark damping constant
!    eqwidl         - equivalent width (a)
!    abundl         - log a
!    ifewid         -
!
    INTEGER:: identl,ionstl,ifewid 
 
    REAL(KIND=8):: xwavel,expotl,gfvall,g1vall,g2vall,g3vall,eqwidl,abundl
  
!
!     /oldval/         last line used by sahan
!
!    idold          - last element atomic number
!    ionold         - last ionization stage
!    epold          - last lower level ex!tation potential
!
    INTEGER:: idold,ionold
    REAL(KIND=8):: epold
     
!
!     /linop/          line opacity
!
!    alinop(mlayer) -
!    alfhln(mlayer) - hydrogen line opacity
!    alphal(mlayer) -
!    avogta(mlayer) -
!    avogtv(mlayer) -
!    agamma(mlayer) -
!    axisqu(mlayer) -
!    modesy         - synthesis mode (-1,0,1)          
!
    INTEGER:: modesy
    REAL(KIND=8), DIMENSION(mlayer):: alinop,alphal,avogta,avogtv,agamma,axisqu,alfhln

!
!     /sauce/
!
!    abnufn(mlayer) -
!    asnufn(mlayer) -
!    ajmsnu(mlayer) -
!    ajaynu(mlayer) -
!    ifscat         -
!    iflime         -
!
    INTEGER:: ifscat, iflime 
    REAL(KIND=8), DIMENSION(mlayer):: abnufn,asnufn,ajmsnu,ajaynu

!
!     /saha/
!
!    anrs(mlayer)   -
!    anrnel(mlayer) -
!    potlow(mlayer) -
!
      REAL(KIND=8), DIMENSION(mlayer):: anrs,anrnel

!
!     /fract/          abundance fractions
!
!    frah0(mlayer)  - neutral hydrogen (h i)
!    frah2(mlayer)  - protons (h ii)
!    framg0(mlayer) - mg i
!    frasi0(mlayer) - si i
!    fraal0(mlayer) - al i
!    frac0(mlayer)  - c i
!    framg1(mlayer) - mg ii
!    frasi1(mlayer) - si ii
!    fraal1(mlayer) - al ii
!    frac1(mlayer)  - c ii
!    frane(mlayer)  - electrons
!    frahe0(mlayer) - neutral helium (he i)
!    frahe2(mlayer) - he ii
!    frahe3(mlayer) - he iii
!
    REAL(KIND=8), DIMENSION(mlayer):: frah0,frah2,framg0,frasi0,fraal0,frac0
    REAL(KIND=8), DIMENSION(mlayer):: framg1,frasi1,fraal1,frac1
    REAL(KIND=8), DIMENSION(mlayer):: frane,frahe0,frahe2,frahe3

!
!     /kappas/         continuous opa!ty
!
!    alfh(mlayer)   -
!    alfhm(mlayer)  -
!    alfh2p(mlayer) -
!    alfh2m(mlayer) -
!    alfmg0(mlayer) -
!    alfsi0(mlayer) -
!    alfal0(mlayer) -
!    alfc0(mlayer)  -
!    alfmg1(mlayer) -
!    alfsi1(mlayer) -
!    alfal1(mlayer) -
!    alfc1(mlayer)  -
!    alfhe(mlayer)  -
!    alfhep(mlayer) -
!    alfhem(mlayer) -
!
    REAL(KIND=8), DIMENSION(mlayer):: alfh,alfhm,alfh2p,alfh2m
    REAL(KIND=8), DIMENSION(mlayer):: alfmg0,alfsi0,alfal0,alfc0,alfmg1,alfsi1,alfal1,alfc1
    REAL(KIND=8), DIMENSION(mlayer):: alfhe,alfhep,alfhem

!
!     /finess/         quality values
!
!    nemerg         -
!    ntau           -
!    nsaha          -
!
    INTEGER nemerg, ntau, nsaha

!
!     /tnew/
!
!    newtmp         -
!    amubar         - sum of n(el)/n(h) * atomic number
!    arabum         - sum of n(el)/n(h)
!
    INTEGER:: newtmp
    REAL(KIND=8):: amubar,arabum
    
!
!     /mapem/          any use?
!
!    ifcor(melmns)  -
!    indexx(melmns) -
!
    INTEGER, DIMENSION(melmns):: ifcor,indexx

!
!     /mapex/          any use?
!
!    ifcox(melmns)  -
!
    INTEGER, DIMENSION(melmns):: ifcox
!
!     /disk/           value of mu
!
!    diskmu         - value of mu
!
    REAL(KIND=8):: diskmu
   
!
!     /spcbrd/         broadened synthetic spectrum
!
!    xbroad(msynth) - array containing broadened spectrum wavelengths
!    ybroad(msynth) - array containing broadened spectrum fluxes
!    nbroad         - number of points in broadened spectrum
!    cbroad         - title of broadened spectrum
!
    INTEGER:: nbroad
    CHARACTER(LEN=mtitle):: cbroad
    REAL(KIND=8), DIMENSION(msynth):: xbroad, ybroad
      
!
!     /spcsyn/         synthetic spectrum
!
!    csynth         - title of synthetic spectrum
!    xsynth(msynth) - array containing synthetic spectrum wavelengths
!    ysynth(msynth) - array containing synthetic spectrum fluxes
!    zsynth(msynth) - array containing optical depth
!    nsynth         - number of points in synthetic spectrum
!
   CHARACTER(LEN=mtitle):: csynth
   INTEGER:: nsynth
   REAL(KIND=8), DIMENSION(msynth):: xsynth, ysynth, zsynth
  
!
!     /spcdip/         observational spectrum
!
!    cdipso         - title of observational spectrum
!    xdipso(mdipso) - array containing observed spectrum wavelengths
!    ydipso(mdipso) - array containing observed spectrum fluxes
!    ndipso         - number of points in observed spectrum
!    radvel         - radial velo!ty of observed spectrum
!
  CHARACTER(LEN=mtitle):: cdipso
  INTEGER:: ndipso
  REAL(KIND=8):: radvel
  REAL(KIND=8), DIMENSION(mdipso):: xdipso, ydipso

!
!     /sins/           synthesis grid range
!
!    xwavlo         - lower wavelength limit
!    xwavhi         - upper wavelength limit
!    xdelta         - step size
!
   REAL(KIND=8)::  xwavlo, xwavhi, xdelta

!
!     /syns/
!
!    vesini         - rotational velo!ty
!    gauwth         - instrumental broadening width
!    xinstp         - delta lambda of empirical instrumental profile
!    yinstp         - response of empirical instrumental profile
!    ninstp         - number of points in empirical instrumental profile
!
   INTEGER:: ninstp
   
   REAL(KIND=8):: vesini,gauwth
   REAL(KIND=8), DIMENSION(minstp):: xinstp, yinstp

!
!     /chicom/
!
!    nfpram         - number of free parameters
!    cfpram         - element name
!    afpram(mfpram) - element starting abundance
!    ywfunc(msynth) - weighting function
!    nwfunc         - number of points in weighting function
!    lineno         - line number (*kcs change 19-06-95*)
!
  CHARACTER(LEN=melmln), DIMENSION(mfpram):: cfpram 
  INTEGER:: nfpram,nwfunc,lineno
  REAL(KIND=8), DIMENSION(mfpram):: afpram
  REAL(KIND=8), DIMENSION(msynth):: ywfunc

!
!     /smear/          microturbulence
!
!    vmicro         - microturbulent velo!ty (km/s)
!
  REAL(KIND=8)::  vmicro
     
!
!     /xmol/           any use?
!
!    fatom(mlayer,20,2) -
!    fmol(mlayer,20)    -
!
    REAL(KIND=8), DIMENSION(mlayer,20,2):: fatom
    REAL(KIND=8), DIMENSION(mlayer,20):: fmol
      
!
!     /state/
!    arho(mlayer)   - density
!
    REAL(KIND=8), DIMENSION(mlayer):: arho
      
!
!     /vgrad/
!
!    gradv(mlayer)  -
!    nograd         -
!
    INTEGER:: nograd  
    REAL(KIND=8), DIMENSION(mlayer):: gradv
     
!
!     /taunox/
!
!    noxtau         -
!
!      integer noxtau
!      common /taunox/ noxtau
!
!
!     /result/         results from exact calculations
!
!    resabs(mlines) - abundance results
!    resews(mlines) - equivalent width results
!    abvars(mlines) - abundance variances from errors
!    covars(mcovar,mcovar) - abundance covariances from errors
!    nreslt         - flag to indicate which type of results available
!    labvar         - logical flag to indicate that errors are available
!
     INTEGER, PARAMETER:: mcovar=mlines
     INTEGER:: nreslt
     LOGICAL:: labvar
!
     REAL(KIND=8), DIMENSION(mlines):: resabs,resews,abvars
     REAL(KIND=8), DIMENSION(mcovar,mcovar):: covars

!
!     /prohe1/ and /pro447/ - he1 stark profile data from
!     Barnard, Cooper and Smith JQSRT 14, 1025, 1974 (for 4471)
!     and Shamey, unpublished PhD thesis, 1969 (for other lines)
!
 
!
    INTEGER, PARAMETER:: mnehe1=8, mlnhe1=3, mtehe1=4, mdlhe1=50
    INTEGER, PARAMETER:: mne447=7, mte447=4, mdl447=80

!
    INTEGER, DIMENSION(mnehe1,mtehe1):: nwlam
    REAL(KIND=8), DIMENSION(mdlhe1,mtehe1,mnehe1,mlnhe1):: prfhe1
    REAL(KIND=8), DIMENSION(mdlhe1,mnehe1,mlnhe1):: dlmhe1
    REAL(KIND=8), DIMENSION(mnehe1):: xnehe1
!
!
    REAL(KIND=8), DIMENSION(mdl447,mte447,mne447):: prf447
    REAL(KIND=8), DIMENSION(mdl447,mne447):: dlm447
    REAL(KIND=8), DIMENSION(mne447):: xne447
!
    INTEGER, DIMENSION(mlayer):: jt
    REAL(KIND=8), DIMENSION(mlayer):: ti0,ti1,ti2
!

     DATA aipot1/&
          13.595D0,   24.581D0,    5.390D0,    9.320D0,    8.296D0,   11.256D0,&
          14.530D0,   13.614D0,   17.418D0,   21.559D0,    5.138D0,    7.644D0,&
           5.984D0,    8.149D0,   10.484D0,   10.357D0,   13.010D0,   15.755D0,&
           4.339D0,    6.111D0,    6.540D0,    6.820D0,    6.740D0,    6.764D0,&
           7.432D0,    7.870D0,    7.860D0,    7.633D0,    7.724D0,    9.391D0,&
           6.000D0,    7.880D0,    9.810D0,    9.750D0,   11.840D0,   13.996D0,&
           4.176D0,    5.692D0,    6.380D0,    6.840D0,    6.880D0,    7.100D0,&
           7.280D0,    7.364D0,    7.460D0,    8.330D0,    7.574D0,    8.991D0,&
           5.785D0,    7.342D0,    8.639D0,    9.010D0,   10.454D0,   12.127D0,&
           3.893D0,    5.210D0,    5.577D0,    5.539D0,    5.464D0,    5.525D0,&
           5.554D0,    5.644D0,    5.671D0,    6.150D0,    5.864D0,    5.939D0,&
           6.022D0,    6.108D0,    6.184D0,    6.254D0,    5.426D0,    7.000D0,&
           7.880D0,    7.980D0,    7.870D0,    8.700D0,    9.000D0,    9.000D0,&
           9.220D0,   10.430D0,    6.106D0,    7.415D0,    7.287D0,    8.430D0,&
           9.300D0,   10.746D0,    4.000D0,    5.277D0,    6.9D0  ,    6.D0  ,&
           6.D0  ,    6.D0                                           /
!
!     second ionisation potentials
!
      DATA aipot2/&
           0.D0  ,   54.403D0,   75.619D0,   18.206D0,   25.149D0,   24.376D0,&
          29.593D0,   35.108D0,   34.980D0,   41.070D0,   47.290D0,   15.031D0,&
          18.823D0,   16.340D0,   19.720D0,   23.400D0,   23.800D0,   27.620D0,&
          31.810D0,   11.868D0,   12.800D0,   13.570D0,   14.650D0,   16.490D0,&
          15.636D0,   16.180D0,   17.050D0,   18.150D0,   20.290D0,   17.960D0,&
          20.510D0,   15.930D0,   18.630D0,   21.500D0,   21.600D0,   24.560D0,&
          27.500D0,   11.027D0,   12.230D0,   13.130D0,   14.320D0,   16.150D0,&
          15.260D0,   16.760D0,   18.070D0,   19.420D0,   21.480D0,   16.904D0,&
          18.860D0,   14.628D0,   16.500D0,   18.600D0,   19.090D0,   21.200D0,&
          25.100D0,   10.001D0,   11.060D0,   10.85D0 ,   10.55D0 ,   10.73D0 ,&
          10.90D0 ,   11.07D0 ,   11.241D0,   12.09D0 ,   11.52D0 ,   11.67D0 ,&
          11.80D0 ,   11.93D0 ,   12.05D0 ,   12.184D0,   13.9D0  ,   14.900D0,&
          16.200D0,   17.700D0,   16.600D0,   17.000D0,   17.000D0,   18.560D0,&
          20.500D0,   18.751D0,   20.420D0,   15.028D0,   16.680D0,   19.000D0,&
          20.000D0,   21.000D0,   22.000D0,   10.144D0,   12.1D0  ,   11.5D0  ,&
          12.D0  ,   12.D0                                           /
!
!     third ionisation potentials
!
      DATA aipot3/&
           0.D0  ,    0.D0  ,  122.451D0,  153.893D0,   37.920D0,   47.871D0,&
          47.426D0,   54.886D0,   62.646D0,   63.500D0,   71.650D0,   80.120D0,&
          28.440D0,   33.460D0,   30.156D0,   35.000D0,   39.900D0,   40.900D0,&
          46.000D0,   51.210D0,   24.750D0,   27.470D0,   29.310D0,   30.950D0,&
          33.690D0,   30.643D0,   33.490D0,   35.160D0,   36.830D0,   39.700D0,&
          30.700D0,   34.210D0,   28.340D0,   32.000D0,   35.900D0,   36.900D0,&
          40.000D0,   43.000D0,   20.500D0,   22.980D0,   25.040D0,   27.130D0,&
          31.000D0,   28.460D0,   31.050D0,   32.920D0,   34.820D0,   37.470D0,&
          28.030D0,   30.490D0,   25.300D0,   31.000D0,   32.000D0,   32.100D0,&
          35.000D0,   36.000D0,   19.177D0,   20.198D0,   21.624D0,   22.1D0  ,&
          22.3D0  ,   23.4D0  ,   24.92D0 ,   20.63D0 ,   21.91D0 ,   22.8D0  ,&
          22.84D0 ,   22.74D0 ,   23.68D0 ,   25.05D0 ,   20.960D0,   21.000D0,&
          22.000D0,   24.000D0,   26.000D0,   25.000D0,   27.000D0,   28.000D0,&
          30.000D0,   34.200D0,   29.800D0,   31.930D0,   25.560D0,   27.000D0,&
          29.000D0,   29.000D0,   33.000D0,   34.000D0,   20.D0  ,   20.0D0  ,&
          20.D0  ,   20.D0                                           /
!
!     fourth ionization potentials
!
      DATA aipot4/&
           0.D0  ,    0.D0  ,    0.D0  ,  217.713D0,  259.366D0,   64.492D0,&
          77.472D0,   77.413D0,   87.138D0,   97.11D0 ,   98.91D0 ,  109.31D0 ,&
         119.99D0 ,   45.141D0,   51.42D0 ,   47.30D0 ,   53.46D0 ,  59.81D0  ,&
          60.92D0 ,   67.15D0 ,   73.7D0  ,   43.26D0 ,   46.71D0 ,  49.1D0   ,&
          51.4D0  ,   54.8D0  ,   51.3D0  ,   54.9D0  ,   55.2D0  ,   59.4D0  ,&
          64.D0  ,   45.71D0 ,   50.13D0 ,   42.944D0,   47.3D0  ,   52.5D0  ,&
          52.6D0  ,   57.D0  ,   61.8D0  ,   34.34D0 ,   38.3D0  ,   46.4D0  ,&
          46.D0  ,   50.D0  ,   48.D0  ,   53.D0  ,   56.D0  ,   59.D0  ,&
          54.4D0  ,   40.734D0,   44.2D0  ,   37.41D0 ,   42.D0  ,   46.D0  ,&
          46.D0  ,   49.D0  ,   49.95D0 ,   36.758D0,   38.98D0 ,   40.4D0  ,&
          41.1D0  ,   41.4D0  ,   42.7D0  ,   44.0D0  ,   39.37D0 ,   41.4D0  ,&
          42.5D0  ,   42.7D0  ,   42.7D0  ,   43.56D0 ,   45.25D0 ,   33.3D0  ,&
          33.D0  ,   35.D0  ,   38.D0  ,   40.D0  ,   39.D0  ,   41.D0  ,&
          44.D0  ,   46.D0  ,   50.7D0  ,   42.32D0 ,   45.3D0  ,   38.D0  ,&
          41.D0  ,   44.D0  ,   43.D0  ,   46.D0  ,   49.D0  ,   28.8D0  ,&
          29.D0  ,   29.D0                                           /
!
!     fifth ionization potentials
!
      DATA aipot5/&
           0.D0  ,    0.D0  ,    0.D0  ,    0.D0  ,  340.22D0 ,  392.08D0 ,&
          97.89D0 ,  113.90D0 ,  114.24D0 ,  126.21D0 ,  138.40D0,  141.27D0 ,&
         153.75D0 ,  166.77D0 ,   65.02D0 ,   72.68D0 ,   67.7D0  ,   75.04D0 ,&
          82.66D0 ,   84.43D0 ,   91.7D0  ,   99.4D0  ,   65.23D0 ,   70.2D0 ,&
          73.0D0  ,   75.5D0  ,   79.5D0  ,   75.5D0  ,   79.9D0  ,   82.6D0  ,&
          87.D0  ,   93.5D0  ,   62.63D0 ,   68.3D0  ,   59.7D0  ,   64.7D0  ,&
          71.0D0  ,   71.6D0  ,   77.0D0  ,   81.5D0  ,   50.55D0 ,   61.2D0  ,&
          55.D0  ,   60.D0  ,   65.D0  ,   62.D0  ,   68.D0  ,   72.D0  ,&
          77.D0  ,   72.28D0 ,   56.D0  ,   58.75D0 ,   66.D0  ,   57.D0  ,&
          62.D0  ,   62.D0  ,   61.6D0  ,   65.55D0 ,   57.53D0 ,   60.D0  ,&
          60.D0  ,   60.D0  ,   60.D0  ,   60.D0  ,   60.D0  ,   60.D0  ,&
          60.D0  ,   60.D0  ,   60.D0  ,   60.D0  ,   66.8D0  ,   50.D0  ,&
          45.D0  ,   48.D0  ,   51.D0  ,   54.D0  ,   57.D0  ,   55.D0  ,&
          58.D0  ,   61.D0  ,   64.D0  ,   68.8D0  ,   56.0D0  ,   61.D0  ,&
          51.D0  ,   55.D0  ,   59.D0  ,   58.D0  ,   62.D0  ,   65.D0  ,&
          60.D0  ,   60.D0                                           /
!
!
END MODULE commons
