MODULE pfdwor

USE commons
USE cutoffs
USE gvalues
USE partfndat

IMPLICIT NONE
      INTEGER,PRIVATE::i,j,k
CONTAINS

 SUBROUTINE partfn(idno,theta,u,eplow)

 IMPLICIT NONE

!     calculates the partition functions for element idno
!
!     completely new version by B. Smalley October 1992
!
!     braket function implemented by B. Smalley April 1993

      INTEGER:: idno
      REAL(KIND=8)::theta,eplow
      REAL(KIND=8),DIMENSION(5)::u

!     interpolate partition function for theta
!
!     uses linear interpolation
!
      DO j=1,5
!
!       locate position in table and adjust for bounds IF necessary
!
!        i=int(5040./(theta*uarray(idno,j,22)))
!        i=max(0,min(i,20))
!
        i=max(0,min(int(5040.0D0/(theta*uarray(idno,j,22))),20))
!
        u(j)=exp((5040.0D0/theta/uarray(idno,j,22)-REAL(i,8))   &  
        *(uarray(idno,j,i+1)-uarray(idno,j,i))     &   
        +uarray(idno,j,i))
      ENDDO
!
!     add braket function IF required
!
      IF (dele(idno,1) >0.0001D0) THEN
        u(1) = u(1) + g(idno,1)*exp(-aipot1(idno)*alge10*theta)     & 
               *braket(1.D0,eplow,dele(idno,1),theta)
      ENDIF
!
      IF (dele(idno,2) > 0.0001D0) THEN
        u(2) = u(2) + g(idno,2)*exp(-aipot2(idno)*alge10*theta)     & 
               *braket(2.D0,2.D0*eplow,dele(idno,2),theta)
      ENDIF
!
      IF (dele(idno,3) >0.0001D0) THEN
        u(3) = u(3) + g(idno,3)*exp(-aipot3(idno)*alge10*theta)     &  
              *braket(3.D0,3.D0*eplow,dele(idno,3),theta)
      ENDIF
!
      IF (dele(idno,4) > 0.0001D0) THEN
        u(4) = u(4) + g(idno,4)*exp(-aipot4(idno)*alge10*theta)     &      
          *braket(4.D0,4.D0*eplow,dele(idno,4),theta)
      ENDIF
!
      IF (dele(idno,5) > 0.0001D0) THEN
        u(5) = u(5) + g(idno,5)*exp(-aipot5(idno)*alge10*theta)     &
                *braket(5.D0,5.D0*eplow,dele(idno,5),theta)
      ENDIF
!
 END SUBROUTINE partfn
!
!***********************************************************************
 FUNCTION braket(a,b,c,d)
 IMPLICIT NONE 
     REAL(KIND=8)::braket,x,y,w,v,a,b,c,d
!
      x=(13.595D0*a*a/b)**1.5
      y=(13.595D0*a*a/c)**1.5
      v=b*alge10*d
      w=c*alge10*d
      braket=x*(0.3333333333D0+v-0.5D0*v*v-0.05555555556D0*v*v*v) &
	-y*(0.3333333333D0+w-0.5D0*w*w-0.05555555556D0*w*w*w)
END FUNCTION braket

END MODULE pfdwor
