MODULE raphson

 IMPLICIT NONE

 CONTAINS

 FUNCTION raphx(fun,dfun,fun0,q,xstart,xacc)
!	Newton-Raphson Method in 1D (x coordinate)
!	to solve the equation fun(x)=fun0
!	input:  fun-external function of x and parameters: y,z,q
!		dfun-external function, partial derivative df/dx
!		fun0-value of the function 
!		q-mass ratio
!	        xstart-first estimate
!		xacc-accuracy
!	output:  raphx-root for which fun=fun0

 USE rochepot

 IMPLICIT NONE
  
 
 INTEGER:: i

 REAL(KIND=8):: raphx
 REAL(KIND=8):: fun,dfun
 REAL(KIND=8):: q,fun0,xstart,xacc,dx

 
 
  raphx=xstart
 
  DO i=1,20
	  dx=(fun(raphx,0.d0,0.d0,q)-fun0)/dfun(raphx,0.d0,0.d0,q)
	  raphx=raphx-dx
	  IF (ABS(dx) < xacc) RETURN
  END DO
 
 END FUNCTION raphx

 FUNCTION raphy(fun,dfun,fun0,q,x0,ystart,yacc)
!
!	Newton-Raphson Method in 1D (y coordinate)
!	to solve the equation fun(y)=fun0
!	input:  fun-external function of y and parameters: x,z,q
!		dfun-external function, partial derivative df/dy
!		fun0-value of the function 
!		q-mass ratio
!	        ystart-first estimate
!		yacc-accuracy
!	output:  raphy-root for which fun=fun0

 USE rochepot

 IMPLICIT NONE

 INTEGER:: i

 REAL(KIND=8):: raphy
 REAL(KIND=8):: fun,dfun
 REAL(KIND=8):: q,x0,ystart,yacc,dy,fun0

  raphy=ystart

  DO i=1,20
     dy=(fun(x0,raphy,0.D0,q)-fun0)/dfun(x0,raphy,0.D0,q)
     raphy=raphy-dy
	  IF (ABS(dy) < yacc) RETURN
  END DO
	
 END FUNCTION raphy

 FUNCTION raphz(fun,dfun,fun0,q,x0,y0,zstart,zacc)
!
!	Newton-Raphson Method in 1D (z coordinate)
!	to solve the equation fun(z)=fun0
!	input:  fun-external function of z and parameters: x,y,q
!		dfun-external function, partial derivative df/dz
!		fun0-value of the function 
!		q-mass ratio
!	        zstart-first estimate
!		zacc-accuracy
!	output:  raphz-root for which fun=fun0
 USE rochepot

 IMPLICIT NONE 
 
 INTEGER:: i

 REAL(KIND=8):: raphz
 REAL(KIND=8):: fun,dfun
 REAL(KIND=8):: zstart,q,dz,zacc,fun0,x0,y0
	
 raphz=zstart
 
 DO i=1,20
    dz=(fun(x0,y0,raphz,q)-fun0)/dfun(x0,y0,raphz,q)
    raphz=raphz-dz
    IF (ABS(dz) < zacc) RETURN
 END DO

 END FUNCTION raphz

 FUNCTION radlob(q)
!
!	returns the volumee radius of the Roche lobe, 0<q<infty
!	q<1 -radius of the less massive star
!	q>1 -radius of the more massive star
! 

 USE rochepot

 IMPLICIT NONE
 
 REAL(KIND=8):: radlob
 REAL(KIND=8):: q,q13

  q13=q**(1.d0/3.d0)
  radlob=0.49d0*q13*q13/(0.69d0*q13*q13+LOG(1.d0+q13))
	
 END FUNCTION radlob

END MODULE raphson