MODULE rochepot
!  Roche potential
 IMPLICIT NONE

 CONTAINS

	FUNCTION pot(x,y,z,q)
	!
	!	input: x,y,z,q
	!	output: normalized Roche potential 
	 IMPLICIT NONE

	 REAL(KIND=8):: pot
	 REAL(KIND=8):: x,y,z,q
	 REAL(KIND=8):: q1,x1,r1,r2
	 
	  q1=1.0D0+q
	  x1=x-1.0D0
	  r1=SQRT(x*x+y*y+z*z)
	  r2=SQRT(x1*x1+y*y+z*z)
	  pot=2.0D0/q1/r1+2.0D0*q/q1/r2+(x-q/q1)*(x-q/q1)+y*y
	
	END FUNCTION pot

	FUNCTION dxpot(x,y,z,q)
	!
	!	input: x,y,z,q
	!	output: partial derivation of the Roche potential after x
	!
	 IMPLICIT NONE

	 REAL(KIND=8):: dxpot
	 REAL(KIND=8):: x,y,z,q
	 REAL(KIND=8):: q1,x1,r1,r2
	 
	  q1=1.d0+q
	  x1=x-1.d0
	  r1=SQRT(x*x+y*y+z*z)
	  r2=SQRT(x1*x1+y*y+z*z)
	  dxpot=-x/q1/r1**3-q*x1/q1/r2**3+x-q/q1
	  dxpot=2.d0*dxpot

	END FUNCTION dxpot


	FUNCTION dypot(x,y,z,q)
	!
	!	input: x,y,z,q
	!	output: partial derivation of the Roche potential after y
	!
	 IMPLICIT NONE

	 REAL(KIND=8):: dypot
	 REAL(KIND=8):: x,y,z,q
	 REAL(KIND=8):: x1,q1,r1,r2

	  q1=1.d0+q
	  x1=x-1.d0
	  r1=SQRT(x*x+y*y+z*z)
	  r2=SQRT(x1*x1+y*y+z*z)
	  dypot=-2.d0/q1/r1**3-2.d0*q/q1/r2**3+2.d0
	  dypot=dypot*y

	END FUNCTION dypot

	FUNCTION dzpot(x,y,z,q)
	!
	!	input: x,y,z,q
	!	output: partial derivation of the Roche potential after z
	!
	 IMPLICIT NONE

	 REAL(KIND=8):: dzpot
	 REAL(KIND=8):: x,y,z,q
	 REAL(KIND=8):: q1,x1,r1,r2
	 
	 q1=1.d0+q
	 x1=x-1.d0
	 r1=SQRT(x*x+y*y+z*z)
	 r2=SQRT(x1*x1+y*y+z*z)
	 dzpot=-2.d0/q1/r1**3-2.d0*q/q1/r2**3
	 dzpot=dzpot*z

	END FUNCTION dzpot

	FUNCTION dxxpot(x,y,z,q)
	!
	!	input: x,y,z,q
	!	output: second partial derivation of the Roche potential after x
	!
	 IMPLICIT NONE
 
	 REAL(KIND=8):: dxxpot
	 REAL(KIND=8):: q,x,y,z
	 REAL(KIND=8):: q1,x1,r1,r2
	 
	  q1=1.d0+q
	  x1=x-1.d0
	  r1=SQRT(x*x+y*y+z*z)
	  r2=SQRT(x1*x1+y*y+z*z)
	  dxxpot=6.d0*x*x/q1/r1**5+6.d0*q*x1*x1/q1/r2**5-2.d0/q1/r1**3&
         -2.d0*q/q1/r2**3+2.d0
	
	END FUNCTION dxxpot

END MODULE rochepot