MODULE common_xpk1a
IMPLICIT NONE

REAL, SAVE     :: f(200), t(200), sigma
INTEGER, SAVE :: ndata

END MODULE common_xpk1a



PROGRAM xpk1a
 
! Code converted using TO_F90 by Alan Miller
! Date: 2001-07-09  Time: 22:28:29
 
!================================================================
!     Driver program for linear least-squares problem
!     (Sect. 5.2)
!================================================================

USE Genetic_Algorithm
IMPLICIT  NONE
INTEGER             :: seed, STATUS
INTEGER, PARAMETER  :: n=2
REAL                :: ctrl(12), x(n), f

! EXTERNAL  fit1a

INTERFACE
  FUNCTION fit1a(n, x) RESULT(fn_val)
    IMPLICIT NONE
    INTEGER, INTENT(IN)  :: n
    REAL, INTENT(IN)     :: x(:)
    REAL                 :: fn_val
  END FUNCTION fit1a
  
  FUNCTION rgauss(xmean,sd) RESULT(RG)
    IMPLICIT NONE
    REAL, INTENT(IN) :: xmean,sd
    REAL             :: rg
  END FUNCTION rgauss
  
END INTERFACE

!     First, initialize the random-number generator

seed = 123456
CALL rninit(seed)

!     Initializations

CALL finit()

!     Set control variables (evolve 50 individuals over 100
!     generations, use defaults values for other input parameters)

ctrl(1:12) = -1
ctrl(1)=100
ctrl(2)=1000

!     Now call pikaia

CALL pikaia(fit1a,n,ctrl,x,f,STATUS)

!     Print the results
WRITE(*,*) ' status: ', STATUS
WRITE(*,*) '      x: ', x
WRITE(*,*) '      f: ', f
WRITE(*,20) ctrl

WRITE(*,*) ' a  = ',0.8+x(1)*0.3,' b  = ',0.3+0.3*x(2)

STOP

20 FORMAT('    ctrl: ', 6F11.6 / t11, 6F11.6)

CONTAINS

!*********************************************************************

SUBROUTINE finit()

!     Synthetic data preparation 

! COMMON/DATA/ f(200),t(200),sigma,ndata

USE common_xpk1a

INTEGER:: i

! a = 1.0  b = 0.5

ndata = 200
sigma = 1.

DO i=1,ndata
    t(i) = 0.1*(i-1)
    f(i) = 1.0 + exp(0.5* t(i))+rgauss(0.0,0.001)
END DO


RETURN
END SUBROUTINE finit

END PROGRAM xpk1a


FUNCTION rgauss(xmean,sd) RESULT(rg)

IMPLICIT NONE

INTEGER :: i
REAL :: x,xmean,sd
REAL :: rg

rg = -6.0

DO i=1,12
    call random_number( harvest = x )
    rg = rg + x
END DO

rg = xmean + sd*rg


RETURN
END FUNCTION rgauss



FUNCTION fit1a(n,x) RESULT(fn_val)
!========================================================
!     Fitness function for linear least squares problem
!     (Sect. 5.2)
!========================================================

USE common_xpk1a
IMPLICIT NONE
INTEGER, INTENT(IN)  :: n
REAL, INTENT(IN)     :: x(:)
REAL                 :: amax,bmax
REAL                 :: fn_val


! COMMON/DATA/ f(200),t(200),sigma,ndata

INTEGER  :: i
REAL     :: a, b, sum
!---------- 1. rescale input variables:

amax = 0.3
bmax = 0.3

a=0.8+x(1)*amax
b=0.3+x(2)*bmax

!---------- 2. compute chi**2

sum=0.

DO  i=1,ndata
  sum=sum + ( (a+exp(b*t(i))-f(i)) )**2
END DO

!---------- 3. define fitness
fn_val=1./sum

RETURN
END FUNCTION fit1a
