!pikaia gaussovka

MODULE common_gauss

 IMPLICIT NONE

 ! COMMON/DATA/ f(200),t(200),sigma,ndata
 REAL, SAVE     :: f(200), t(200), sigma
 INTEGER, SAVE  :: ndata

 END MODULE common_gauss

PROGRAM gauss
 
USE Genetic_Algorithm

 IMPLICIT NONE
 INTEGER             :: seed, STATUS
 INTEGER, PARAMETER  :: n=3  !mame tri parametry
 REAL                :: ctrl(12), x(n), f

INTERFACE
 
  FUNCTION fit1a(n, x) RESULT(fn_val)
    IMPLICIT NONE
    INTEGER, INTENT(IN)  :: n
    REAL, INTENT(IN)     :: x(:)
    REAL                 :: fn_val
  END FUNCTION fit1a

  FUNCTION rgauss(xmean,sd) RESULT(RG)
    IMPLICIT NONE
    REAL, INTENT(IN) :: xmean,sd
    REAL             :: rg
  END FUNCTION rgauss

END INTERFACE

seed = 123456

CALL rninit(seed)

! Initializations

CALL finit()

! Set control variables ctrl()
! -1 is default 

ctrl(1:12) = -1
ctrl(1) = 100
ctrl(2) = 500

! Now call pikaia

CALL pikaia(fit1a,n,ctrl,x,f,STATUS)

!     Print the results
WRITE(*,*) ' status: ', STATUS
WRITE(*,*) '      x: ', x
WRITE(*,*) '      f: ', f
WRITE(*,20) ctrl
STOP

20 FORMAT('    ctrl: ', 6F11.6 / t11, 6F11.6)

CONTAINS

SUBROUTINE finit()

!     Synthetic data preparation 

! COMMON/DATA/ f(200),t(200),sigma,ndata

USE common_gauss

 IMPLICIT NONE

  INTEGER:: i
  
   ndata=200

   !f=a*e**(-(x-b)**2/(2*c**2))   a=1.,b=1.,c=1.

  DO i=1,ndata
    t(i) = 0.1*(i-1)
    f(i) = 1.*exp(-(t(i)-1.)**2/(2.*1.**2))+rgauss(0.0,0.1)
  END DO

 sigma=1.

 RETURN
END SUBROUTINE finit

END PROGRAM gauss

FUNCTION rgauss(xmean,sd) RESULT(rg)

IMPLICIT NONE

INTEGER :: i
REAL :: x,xmean,sd
REAL :: rg

rg = -6.0

DO i=1,12
    call random_number( harvest = x )
    rg = rg + x
END DO

rg = xmean + sd*rg
RETURN
END FUNCTION rgauss

FUNCTION fit1a(n,x) RESULT(fn_val)
!========================================================
!     Fitness function for linear least squares problem
!     (Sect. 5.2)
!========================================================

USE common_gauss
IMPLICIT NONE
INTEGER, INTENT(IN)  :: n
REAL, INTENT(IN)     :: x(:)
REAL                 :: amax,bmax,cmax
REAL                 :: fn_val

! COMMON/DATA/ f(200),t(200),sigma,ndata

 INTEGER  :: i
 REAL     :: a, b,c, suma
 !---------- 1. rescale input variables:
 amax = 1.0
 bmax = 1.0
 cmax=1.0

 a=0.5+x(1)*amax
 b=0.5+x(2)*bmax
 c=0.5+x(3)*cmax

!---------- 2. compute chi**2
 suma=0.
  DO  i=1,ndata
      suma=suma + ( (a*exp(-(t(i)-b)**2/(2.*c**2))-f(i))/sigma )**2
  END DO
!---------- 3. define fitness

fn_val=1./suma

 RETURN
END FUNCTION fit1a
